
# Formee- The terminal forms

Formee is a tool that provides an easy way to create, edit and manage all of your forms from the command line. It uses a powerful GraphQL API and strives to make the process of working with forms as easy and simple as possible.

![Formee Logo](docs/docs_assets/images/logo.svg)


## Badges

[![MIT License](https://img.shields.io/apm/l/atomic-design-ui.svg?)](https://github.com/Arpan-206https://docs.formee.hackersreboot.tech/learn/01-getting%20started/formee/blob/main/LICENSE)
[![Python 3.8 or above](https://img.shields.io/badge/python-%5E3.8-blue)](https://python.org/)
[![Hasura](https://img.shields.io/badge/Built%20With-Hasura-yellowgreen)](https://hasura.io)


## Installation

1. Install *formee* with pip

```bash
pip3 install formee
```

2. Use the Github repository

    ```bash
    git clone https://github.com/Arpan-206/formee.git
    cd formee
    ```

    - If you use poetry, then:
        ```bash
        poetry install
        ```
    - Otherwise, use pip
        ```bash
        pip3 install -r requirements.txt
        ```

## Usage

1. [Install the CLI.](#Installation)
2. Run the command
```bash
python3 -m formee
```
Or just
```bash
formee
```
3. You're good to go.

## Learn
If you want to learn how to use Formee, then you can visit [the learn segment in the docs](https://docs.formee.hackersreboot.tech/learn/01-getting%20started).
## Documentation
Access the Documentation over 
[here](https://docs.formee.hackersreboot.tech/).


## License

[MIT](https://github.com/Arpan-206/formee/blob/main/LICENSE)



## Roadmap

- Add more type of fields
- Work on security
- Work on Auth
- Improve WebUI
- Improve runtime


## Authors
- [@Arpan-206](https://github.com/Arpan-206)


## Feedback
If you have any feedback, please reach out to us at arpan@hackersreboot.tech.


## Contributing
Contributions are always welcome!
See `contributing.md` for ways to get started.
Please adhere to this project's `code of conduct`.